## Splashscreen Settings##################################
##
## A custom screen that allows players to set their accessibility settings the first
## time they launch the game. Borrows elements from the Preferences screen in
## screens.rpy, and will need to be manually adjusted.
## https://www.renpy.org/doc/html/splashscreen_presplash.html

screen splash_settings():

    frame:

        align 0.5, 0.5
        left_margin 200
        right_margin 200
        top_margin 150
        bottom_margin 150

        left_padding 100
        right_padding 100
        top_padding 50
        bottom_padding 50

        vbox:

            xalign 0.5
            spacing 30

            label _("Accessibility Settings") xalign 0.5
            label _("These options can be changed again at any time in the menu.") xalign 0.5

            hbox:

                # xfill True
                xalign 0.5

                vbox:

                    spacing 5

                    style_prefix "radio"
                    label _("Toggles") xalign 0.5

                    textbutton _("Audio Titles") action ToggleVariable("persistent.sound_captions") alt "Toggle Sound Captions" xalign 0.5
                    textbutton _("Image Descriptions") action ToggleVariable("persistent.image_captions") alt "Toggle Image Descriptions" xalign 0.5
                    textbutton _("Screenshake") action ToggleField(persistent,"screenshake",true_value=True,false_value=False) alt "Toggle Screen Shake" xalign 0.5

                    ## Self-voicing does not work on smartphone devices, so this option only shows if the user is playing on a PC.
                    if renpy.variant("pc"):

                        textbutton _("Self-Voicing") action Preference("self voicing", "toggle") alt "Toggle Self-Voicing" xalign 0.5

                vbox:

                    spacing 5

                    style_prefix "radio"
                    label _("Typeface") xalign 0.5

                    textbutton _("NotoSans") action [gui.SetPreference("font", "gui/fonts/NotoSans-Regular.ttf"), SetVariable("typeface", "NotoSans"), gui.SetPreference("dialogue_spacing", 2)] alt "Change to NotoSans" xalign 0.5

                    textbutton _("DejaVuSans") action [gui.SetPreference("font", "DejaVuSans.ttf"), SetVariable("typeface", "DejaVuSans"), gui.SetPreference("dialogue_spacing", 2.01)] alt "Change to DejaVuSans" xalign 0.5

                    textbutton _("OpenDyslexic") action [gui.SetPreference("font", "_OpenDyslexic3-Regular.ttf"), SetVariable("typeface", "OpenDyslexic"), gui.SetPreference("dialogue_spacing", -4)]  alt "Change to OpenDyslexic" xalign 0.5
                    ## Note: Having so many actions set to a single radio button
                    ## will cause some of the preferences in the same category to appear
                    ## to be all selected, causing players some confusion. Some numbers
                    ## have been set to 2.01 to prevent this from happening.

                # vbox:
                #
                #     spacing 5
                #
                #     style_prefix "radio"
                #     label _("Text Color") xalign 0.5
                #
                #     textbutton _("White") action gui.SetPreference("color", "#ffffff") alt "Change to White Text" xalign 0.5
                #     textbutton _("Cream") action gui.SetPreference("color", "#FBF0D9") alt "Change to Cream Text" xalign 0.5
                #     textbutton _("Black") action gui.SetPreference("color", "#000000") alt "Change to Black Text" xalign 0.5

            hbox:

                #xfill True
                xalign 0.5

                vbox:

                    spacing 5

                    style_prefix "radio"
                    label _("Font Size") xalign 0.5

                    if renpy.variant("pc"):
                        textbutton _("Large") action gui.SetPreference("size", 33) alt "Change to Large Size Text" xalign 0.5
                        textbutton _("Regular") action gui.SetPreference("size", 31) alt "Change to Regular Size Text" xalign 0.5

                    elif renpy.variant("mobile"):

                        if typeface == "OpenDyslexic":
                            textbutton _("Large") action gui.SetPreference("phone_size", 32) xalign 0.5
                            textbutton _("Regular") action gui.SetPreference("phone_size", 30) xalign 0.5
                            ## Note: due to the unique nature of the OpenDyslexic font, it needs
                            ## to be just slightly smaller so as to not break the GUI

                        else:
                            textbutton _("Large") action gui.SetPreference("phone_size", 42) xalign 0.5
                            textbutton _("Regular") action gui.SetPreference("phone_size", 40) xalign 0.5

                # vbox:
                #
                #     spacing 5
                #
                #     style_prefix "radio"
                #     label _("Textbox") xalign 0.5
                #
                #     if renpy.variant("pc"):
                #
                #         textbutton _("Black") action [gui.SetPreference("ADVtextbox", "gui/textbox_1.png"), gui.SetPreference("NVLtextbox", "gui/nvl_1.png")] alt "Change to Black Textbox" xalign 0.5
                #         textbutton _("White") action [gui.SetPreference("ADVtextbox", "gui/textbox_2.png"), gui.SetPreference("NVLtextbox", "gui/nvl_2.png")]  alt "Change to White Textbox" xalign 0.5
                #
                #     elif renpy.variant("mobile"):
                #
                #         textbutton _("Black") action [gui.SetPreference("m_ADVtextbox", "gui/phone/textbox_1.png"), gui.SetPreference("m_NVLtextbox", "gui/phone/nvl_1.png")] xalign 0.5
                #         textbutton _("White") action [gui.SetPreference("m_ADVtextbox", "gui/phone/textbox_2.png"), gui.SetPreference("m_NVLtextbox", "gui/phone/nvl_2.png")] xalign 0.5

                vbox:

                    spacing 5

                    style_prefix "radio"
                    label _("Line Spacing") xalign 0.5

                    if typeface == "OpenDyslexic":

                        textbutton _("Taller") action gui.SetPreference("dialogue_spacing", -2) alt "Change the height of the space between lines of dialogue" xalign 0.5
                        textbutton _("Regular") action gui.SetPreference("dialogue_spacing", -4) alt "Change the height of the space between lines of dialogue" xalign 0.5

                    elif typeface == "DejaVuSans":

                        textbutton _("Taller") action gui.SetPreference("dialogue_spacing", 4.01) alt "Change the height of the space between lines of dialogue" xalign 0.5
                        textbutton _("Regular") action gui.SetPreference("dialogue_spacing", 2.01) alt "Change the height of the space between lines of dialogue" xalign 0.5

                    else:

                        textbutton _("Taller") action gui.SetPreference("dialogue_spacing", 4) alt "Change the height of the space between lines of dialogue" xalign 0.5
                        textbutton _("Regular") action gui.SetPreference("dialogue_spacing", 2) alt "Change the height of the space between lines of dialogue" xalign 0.5

            textbutton _("Confirm") action Return() xalign 0.5

## Extras screens ###########################################
##
## Screens that includes Image Galleries, Music Room, and Dev Notes.
## https://www.renpy.org/doc/html/rooms.html

## We let Ren'Py resize our images so we don't have to make buttons in another
## program.

## These background buttons are 480x270
image bglock_button = "gui/button/bg_locked.jpg"

image kitchen1_button = im.FactorScale("images/BG/kitchen1.webp", 0.125)
image the_jp_mansion_day_button = im.FactorScale("images/BG/the_jp_mansion_day.webp", 0.125)
image Kitchen1_Daylight_button = im.FactorScale("images/BG/Kitchen1_Daylight.webp", 0.125)
image living_room1_button = im.FactorScale("images/BG/living_room1.webp", 0.125)
image bath3_button = im.FactorScale("images/BG/bath3.webp", 0.125)

# image Bathroom1_Day_button = im.FactorScale("images/BG/Bathroom1_Day.webp", 0.25)
# image Bedroom_Day_Indoor_Light_button = im.FactorScale("images/BG/Bedroom_Day_Indoor_Light.webp", 0.25)
# image City_street_day_button = im.FactorScale("images/BG/City_street_day.webp", 0.25)
# image Living_Room1_Afternoon_Light_button = im.FactorScale("images/BG/Living_Room1_Afternoon_Light.webp", 0.25)
# image Realistic_valley_18_button = im.FactorScale("images/BG/Realistic_valley_18.webp", 0.25)
# image Realistic_valley_33_button = im.FactorScale("images/BG/Realistic_valley_33.webp", 0.25)
# image bath2_button = im.FactorScale("images/BG/bath2.webp", 0.25)
# image city1_button = im.FactorScale("images/BG/city1.webp", 0.25)
# image kitchen_day_button = im.FactorScale("images/BG/kitchen_day.webp", 0.25)


## These sprite buttons are 290x290
image sangry_button = Crop((170, 245, 290, 290), "steven angry")
image shappy_button = Crop((170, 245, 290, 290), "steven happy")
image sneutral_button = Crop((170, 245, 290, 290), "steven neutral")
image sshocked_button = Crop((170, 245, 290, 290), "steven shocked")
image ssurprised_button = Crop((170, 245, 290, 290), "steven surprised")
image supset_button = Crop((170, 245, 290, 290), "steven upset")
image dneutral_button = Crop((170, 245, 290, 290), "dee neutral")
image eneutral_button = Crop((170, 245, 290, 290), "ethan")
# image eangry_button = Crop((170, 245, 290, 290), "ethan angry")
image bneutral_button = Crop((170, 245, 290, 290), "bob neutral")
image bangry_button = Crop((170, 245, 290, 290), "bob angry")
image poo_button = Crop((170, 0, 290, 290), "poo")
image spritelock_button = "gui/button/sprite_locked.jpg"
image black_button = Crop((170, 0, 1, 1), "black")

init python:

    g_bg = Gallery()

    # Backgrounds for the BG Gallery
    g_bg.button("kitchen1")
    g_bg.unlock_image("kitchen1")

    g_bg.button("the_jp_mansion_day")
    g_bg.image("the_jp_mansion_day")
    g_bg.unlock("the_jp_mansion_day")

    g_bg.button("Kitchen1_Daylight")
    g_bg.image("Kitchen1_Daylight")
    g_bg.unlock("Kitchen1_Daylight")

    g_bg.button("living_room1")
    g_bg.image("living_room1")
    g_bg.unlock("living_room1")

    g_bg.button("bath3")
    g_bg.image("bath3")
    g_bg.unlock("bath3")

    # Sprites for the Sprite Gallery
    # We put a background in the first spot so Eileen isn't floating in a void.

    g_sprite = Gallery()

    for mood in ("angry", "blink", "happy", "neutral", "shocked", "surprised", "upset"):
        thing = "steven %s" % (mood,)
        g_sprite.button(thing)
        g_sprite.unlock("black", thing)
        g_sprite.image("black", thing)

    g_sprite.button("black")
    g_sprite.unlock_image("black")

    for thing in ("dee neutral","poo", "ethan"):
        g_sprite.button(thing)
        g_sprite.unlock("black", thing)
        g_sprite.image("black", thing)

    for person in ("bob", ):
        for mood in ("neutral", "angry"):
            thing = "%s %s" % (person, mood)
            g_sprite.button(thing)
            g_sprite.unlock("black", thing)
            g_sprite.image("black", thing)

    # The button used for locked images
    g_bg.locked_button = "bglock_button"
    g_sprite.locked_button = "spritelock_button"

    # The transition used when switching images.
    g_bg.transition = dissolve
    g_sprite.transition = dissolve

    # MusicRoom instance.
    mr = MusicRoom(fadeout=1.0)

    # Add music files.
    mr.add("audio/music/yam655 - Crappy Game OST - Menu.ogg", always_unlocked=True)
    mr.add("audio/music/yam655 - Crappy Game OST - At Home.ogg")
    mr.add("audio/music/yam655 - Crappy Game OST - Outside Boss House.ogg")
    mr.add("audio/music/yam655 - Crappy Game OST - Party.ogg")
    # mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 01 Priceless Poop.ogg")
    mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 02 Out of Earshot.ogg")
    # mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 03 Hear my Toot.ogg")
    # mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 04 My Hair Smells like Poop.ogg")
    # mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 05 Pooping about Singing.ogg")
    # mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 06 Distractions While I Poop.ogg")
    # mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 07 How many songs have been lost-.ogg")
    mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 08 Life is Full of Poop.ogg")
    # mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 09 Pooping and Singing.ogg")
    # mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 10 Tooting Songs.ogg")
    # mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 11 Today I got Some Gas.ogg")
    mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 12 When You Leave.ogg")
    mr.add("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 13 Inspired to Poop.ogg", always_unlocked=True)


## Extras Navigation screen ############################################################
##
## This is the same as the Game Menu Navigation screen, but just for the Extras.

screen extras_navigation():

    vbox:
        style_prefix "navigation"

        xpos gui.navigation_xpos
        yalign 0.5

        spacing gui.navigation_spacing

        textbutton _("Achievements") action ShowMenu("achievements") alt "Achievements"

        textbutton _("Sprite Gallery") action ShowMenu("sprite_gallery") alt "Sprite Gallery"

        textbutton _("Background Gallery") action ShowMenu("bg_gallery") alt "Background Gallery"

        textbutton _("Music Room") action ShowMenu("music_gallery") alt "Music Room"

        textbutton _("Developer Notes") action ShowMenu("dev_notes") alt "Developer Notes"

        textbutton _("Return") action Return() alt "Return"

## Extras Menu screen #######################################
##
## This is the same as the Game Menu screen, but just for the Extras.

screen extras_menu(title, scroll=None, yinitial=0.0):

    style_prefix "game_menu"

    if main_menu:
        add gui.main_menu_background
    else:
        add gui.game_menu_background

    frame:
        style "game_menu_outer_frame"

        hbox:

            ## Reserve space for the navigation section.
            frame:
                style "game_menu_navigation_frame"

            frame:
                style "game_menu_content_frame"

                if scroll == "viewport":

                    viewport:
                        yinitial yinitial
                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        vbox:
                            transclude

                elif scroll == "vpgrid":

                    vpgrid:
                        cols 1
                        yinitial yinitial

                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        transclude

                else:

                    transclude

    label title

    use extras_navigation

## Sprite Gallery screen ######################################
##
## This is a simple screen that shows buttons that display a sprite imposed on a
## background.

screen sprite_gallery():

    tag menu

    ## This use statement includes the extras_menu screen inside this one.
    use extras_menu("Sprite Gallery"):

        grid 5 2:

            xfill True
            yfill True

            ## Call make_button to show a particular button.
            # add g_sprite.make_button("sprite", "sprite_button")

            # add g_sprite.make_button("steven angry", "sangry_button")
            add g_sprite.make_button("steven happy", "shappy_button")
            add g_sprite.make_button("steven neutral", "sneutral_button")
            add g_sprite.make_button("steven shocked", "sshocked_button")
            # add g_sprite.make_button("steven surprised", "ssurprised_button")
            add g_sprite.make_button("steven upset", "supset_button")
            add g_sprite.make_button("dee neutral", "dneutral_button")
            add g_sprite.make_button("ethan", "eneutral_button")
            # add g_sprite.make_button("ethan angry", "eangry_button")
            add g_sprite.make_button("bob neutral", "bneutral_button")
            add g_sprite.make_button("bob angry", "bangry_button")
            add g_sprite.make_button("poo", "poo_button")
            add g_sprite.make_button("black", "black_button")


## Background Gallery screen ############################################################
##
## This is a simple screen that shows buttons that display a background.
## You can easily adapt this screen to make a CG or concept art screen.

screen bg_gallery():

    tag menu

    ## This use statement includes the extras_menu screen inside this one.
    use extras_menu("Background Gallery"):

        grid 1 5:

            xfill True
            yfill True

            ## Call make_button to show a particular button.
            # add g_bg.make_button("background", "bg_button")

            add g_bg.make_button("kitchen1", "kitchen1_button", xalign=0.5, yalign=0.5)
            add g_bg.make_button("the_jp_mansion_day", "the_jp_mansion_day_button", xalign=0.5, yalign=0.5)
            add g_bg.make_button("Kitchen1_Daylight", "Kitchen1_Daylight_button", xalign=0.5, yalign=0.5)
            add g_bg.make_button("living_room1", "living_room1_button", xalign=0.5, yalign=0.5)
            add g_bg.make_button("bath3", "bath3_button", xalign=0.5, yalign=0.5)

            # add g_bg.make_button("Bathroom1_Day", "Bathroom1_Day_button", xalign=0.5, yalign=0.5)
            # add g_bg.make_button("Bedroom_Day_Indoor_Light", "Bedroom_Day_Indoor_Light_button", xalign=0.5, yalign=0.5)
            # add g_bg.make_button("City_street_day", "City_street_day_button", xalign=0.5, yalign=0.5)
            # add g_bg.make_button("Living_Room1_Afternoon_Light", "Living_Room1_Afternoon_Light_button", xalign=0.5, yalign=0.5)
            # add g_bg.make_button("Realistic_valley_18", "Realistic_valley_18_button", xalign=0.5, yalign=0.5)
            # add g_bg.make_button("Realistic_valley_33", "Realistic_valley_33_button", xalign=0.5, yalign=0.5)
            # add g_bg.make_button("bath2", "bath2_button", xalign=0.5, yalign=0.5)
            # add g_bg.make_button("city1", "city1_button", xalign=0.5, yalign=0.5)
            # add g_bg.make_button("kitchen_day", "kitchen_day_button", xalign=0.5, yalign=0.5)
            # add g_bg.make_button("kitchen1", "kitchen1_button", xalign=0.5, yalign=0.5)


## Music Gallery screen ############################################################
##
## This is a simple screen that shows buttons that play a music track.

screen music_gallery():

    tag menu

    ## This use statement includes the extras_menu screen inside this one.
    use extras_menu("Music Room"):

        vbox:

            xalign 0.5
            yalign 0.5

            # The buttons that play each track.

            textbutton "OST - Menu" action mr.Play("audio/music/yam655 - Crappy Game OST - Menu.ogg")
            textbutton "OST - At Home" action mr.Play("audio/music/yam655 - Crappy Game OST - At Home.ogg")
            textbutton "OST - Outside Boss House" action mr.Play("audio/music/yam655 - Crappy Game OST - Outside Boss House.ogg")
            textbutton "OST - Party" action mr.Play("audio/music/yam655 - Crappy Game OST - Party.ogg")
            # textbutton "Priceless Poop" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 01 Priceless Poop.ogg")
            textbutton "Out of Earshot" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 02 Out of Earshot.ogg")
            # textbutton "Hear My Toot" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 03 Hear my Toot.ogg")
            # textbutton "My Hair Smells like Poop" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 04 My Hair Smells like Poop.ogg")
            # textbutton "Pooping about Singing" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 05 Pooping about Singing.ogg")
            # textbutton "Distractions While I Poop" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 06 Distractions While I Poop.ogg")
            # textbutton "How many songs have been lost?" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 07 How many songs have been lost-.ogg")
            textbutton "Life is Full of Poop" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 08 Life is Full of Poop.ogg")
            # textbutton "Pooping and Singing" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 09 Pooping and Singing.ogg")
            # textbutton "Tooting Songs" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 10 Tooting Songs.ogg")
            # textbutton "Today I got Some Gas" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 11 Today I got Some Gas.ogg")
            textbutton "When You Leave" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 12 When You Leave.ogg")
            textbutton "Inspired to Poop" action mr.Play("audio/music/Mr. Beany's Bitty Band - Putting the Crap back in Crapcapella - 13 Inspired to Poop.ogg")


            null height 20

            hbox:
            # Buttons that let us advance through tracks.
                textbutton "Previous" action mr.Previous() alt "Previous Song"
                textbutton "Next" action mr.Next() alt "Next Song"

            null height 20

        # Start the music playing on entry to the music room.
        on "replace" action mr.Play()

        ## Restore the main menu music upon leaving.
        ## You can actually comment this out if you want to let players enjoy the music
        ## while looking at the other screens.
        # on "replaced" action Play("music", "audio/title-song.mp3")

## Dev Notes screen ########################################
##
## This screen contains a message for players after they beat the entire game.
## We borrowed the base of this screen from the About screen.

screen dev_notes():

    tag menu

    ## This use statement includes the extras_menu screen inside this one. The
    ## vbox child is then included inside the viewport inside the extras_menu
    ## screen.
    use extras_menu(_("Developer's Notes"), scroll="viewport"):

        style_prefix "about"

        vbox:

            ## gui.dev_notes is usually set in options.rpy.
            if gui.dev_notes:
                text "[gui.dev_notes!t]\n"

## Type your special message here.
define gui.dev_notes = _p("""This is yam655, also known as Steven.\n
I'd like to say this game is entirely a work of fiction and does not
portray any amount of autobiographical material.\n
I'd like to.\n
As the song goes, "Life is full of poop."\n
When life give you poop, I hope it cleans up easily.
""")

## Achievements screen ######################################
##
## This custom screen contains a list of achievements for the game.
## Official Documentation: https://www.renpy.org/doc/html/achievement.html
## Additional writeup by bobcgames:
## Part 1: http://bobcgames.com/blog/archives/48/
## Part 2: http://bobcgames.com/blog/archives/54/
## Roselia Achievements Module: https://github.com/OlegWock/Roselia-achievements/

## List achievements that are either True or False here
python early:
    simple_achievement_list = (
        # ("Achievement Name", "Description when not unlocked", "Description when unlocked"),
        ("Finished work day.", "Super easy.", "Started a new game"),
        ("Fired by text message.", "Bad ending.", "Missed a required work event."),
        ("No bathroom. No problem.", "Special skill.", "Pooped outside."),
        ("In front of the boss.", "Bad ending.", "Pooped self in front of boss and his spouse."),
        ("Too embarrassed to work.", "Bad ending.", "Ran away and didn't come back to work."),
        ("Stained a wall.", "Bad ending.", "Tried to hide pooping in front of boss, and stained his wall."),
        ("Winner! Kept the job!", "Good ending.", "I hope you like the job. You still have it."),
        ("Completionist", "Secret.", "Read all of the game.")
    )


## Registers your achievements to work on backend systems such as Steam
## Be sure to match the name of the achievement in achievement_list and
## the corresponding achievement.grant or achievement.progress in the script.
## Notes for testing: you need at least 2 achievements for it to work

init python:

    for a, lockdesc, unlockdesc in simple_achievement_list:

        ## This auto-populates the achievements to register on the backend
        achievement.register(a)



## Our actual achievements screen
screen achievements():

    tag menu

    ## This use statement includes the extras_menu screen inside this one. The
    ## vbox child is then included inside the viewport inside the extras_menu
    ## screen.
    use extras_menu(_("Achievements"), scroll="viewport"):

        ## This screen doesn't need anything fancy, so we borrow the style
        ## from the About screen, which just displays text.
        style_prefix "about"

        vbox:

            ## This auto-populates our list of simple achievements that will appear
            ## in the screen, so we don't have to manually type each one out.
            for aname, lockdesc, unlockdesc in simple_achievement_list:

                if achievement.has(aname):

                    text "[aname]: [unlockdesc]"

                else:

                    text "[aname]: [lockdesc]"

            ## We have to type each integer based achievement however

            text "[persistent.readtotal]% of the game read"

## End Credits Scroll ############################################################
## ATL for scrolling screen object. In this case, credits roll.
## Speed is the time for object to move up from initial ypos to finish ypos.

## Code Source: https://lemmasoft.renai.us/forums/viewtopic.php?t=42667

transform credits_scroll(speed):
    ypos 900
    linear speed ypos -5000
    ## Adjust these numbers to be the height of your end credits. Both numbers
    ## should be the same.

## Credits screen.

screen credits():

    ## Ensure that the game_menu screens don't appear and interrupt the credits.
    key "K_ESCAPE" action NullAction()
    key "K_MENU" action NullAction()
    key "mouseup_3" action NullAction()

    style_prefix "credits"

    ## If a player has seen the end credits before, this button appears.
    if persistent.credits_seen:

        textbutton _("Skip End Credits") action Jump("skip_credits") xalign 1.0 yalign 1.0

    timer 22.0 action Return()
    ## Adjust this number to control when the Credits screen is hidden and the game
    ## returns to its normal flow.
    ## Ideally, there is some wait time after the the credits reaches the end.

    frame at credits_scroll(20.0):
        ## Adjust this number to control the speed at which the credits scroll.
        background None
        xalign 0.5

        vbox:
            label "Credits" xalign 0.5

            null height 200

            # text "Producer" size 100
            # null height 50
            # text "yam655"

            #null height 200

            # text "Logo" size 100
            # null height 50
            # text "Lorem Ipsum"

            #null height 200

            text "Script" size 100
            null height 50
            text "yam655"

            null height 200

            text "Art" size 100
            null height 50

            text "Mannequin by HelloAR14"

            null height 50

            text "Uncle Mugen"

            null height 50

            text "{a=thatnewdevgirl.itch.io}thatnewdevgirl.itch.io{/a}"

            null height 50

            text "{a=visual-novel-assets.itch.io}visual-novel-assets.itch.io{/a}"

            null height 200

            text "Soundtrack" size 100
            null height 50

            text "{a=https://yam655.bandcamp.com/}yam655{/a}'s {a=https://yam655.bandcamp.com/a-crappy-game-ost}official soundtrack EP{/a}."

            null height 100

            text "Lo-fi Acappella"
            null height 50
            text "{a=https://mrbeany.bandcamp.com/}Mr. Beany's Bitty Band{/a}'s album {a=https://mrbeany.bandcamp.com/album/putting-the-crap-back-in-crapcapella}Putting the Crap Back in Crapcapella{/a}"
            null height 50
            text "(This album inspired this game.)"

            null height 200

            text "GUI Template" size 100
            null height 50

            hbox:

                xalign 0.5
                spacing 200

                text "BáiYù"

                text "bobcgames"

            null height 50

            hbox:

                xalign 0.5
                spacing 200

                text "minute"

                text "npckc"

            null height 200

            # text "Programming" size 100

            text "Special Thanks" size 100
            null height 50

            text "Everyone that poops."

            null height 50

            text "(That probably includes you!)"

            null height 100

            text "(And if you can't poop and still played my game, I really, truly appreciate it. You're great, too! May your days be full of health, whether or not you ever poop again!)"

            null height 200

            # text "Trailer" size 100
            # null height 50
            # text "Lorem Ipsum"

            # null height 200

            # text "Voiceover" size 100
            # null height 50

            # hbox:
            #     xalign 0.5
            #     spacing 250

            #     vbox:

            #         text "Lorem Ipsum"

            #     vbox:

            #         text "Lorem Ipsum"

            # null height 200

            # text "Backers" size 100
            # null height 50

            # hbox:

            #     xalign 0.5
            #     spacing 100
            #     style_prefix "backercredits"

            #     vbox:

            #         text "Lorem Ipsum"

            #     vbox:

            #         text "Lorem Ipsum"

            #     vbox:

            #         text "Lorem Ipsum"

            text "Made with Ren'Py [renpy.version_only]." size 100

            null height 450

            text "Thanks for Playing!" size 100

style credits_hbox:
    spacing 40
    ysize 30

style credits_label_text:
    xalign 0.5
    size 200
    text_align 0.5

style credits_text:
    xalign 0.5
    size 80
    justify True
    text_align 0.5
    color "#ffffff"

style backercredits_text:
    xalign 0.5
    size 50
    justify True
    text_align 0.5
    color "#ffffff"


## Results Screen ############################################################
## A screen that displays how much of the game the player has seen.

## Code Source: https://lemmasoft.renai.us/forums/viewtopic.php?t=39859
## Official Documentation of function: https://www.renpy.org/doc/html/other.html#renpy.count_dialogue_blocks

# This creates a percentage based on how much of the game the player has seen.
init python:

    numblocks = renpy.count_dialogue_blocks()

    def percent():

        global readtotal
        readtotal = renpy.count_seen_dialogue_blocks()* 100 / numblocks
        persistent.readtotal = readtotal
        ## This is displayed in our Achievements screen.

default readtotal = 0

screen results():

    zorder 200

    vbox:
        xalign .5
        yalign .2
        spacing 45

        text "Script Seen: [readtotal]%" color "#fff"

## TODO: Figure out how to get total game time working properly
## https://lemmasoft.renai.us/forums/viewtopic.php?t=40407
## Official Documentation of function: https://www.renpy.org/doc/html/other.html#renpy.get_game_runtime

# default playtime = 0

# init 2 python:

#     def total_playtime(d):
#         renpy.store.playtime += renpy.get_game_runtime()
#         #renpy.clear_game_runtime()
#         d["playtime"] = renpy.store.playtime

    # config.save_json_callbacks = [total_playtime]
